Address comments from an earlier CL

Change-Id: I6a47cb76e6babeea422791fb6b1887dd244c2f5e
Reviewed-on: https://dart-review.googlesource.com/c/sdk/+/125120
Commit-Queue: Brian Wilkerson <brianwilkerson@google.com>
Reviewed-by: Samuel Rawlins <srawlins@google.com>
Reviewed-by: Paul Berry <paulberry@google.com>
diff --git a/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_listener.dart b/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_listener.dart
index ce66ed8..0f977ed 100644
--- a/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_listener.dart
+++ b/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_listener.dart
@@ -86,7 +86,7 @@
   }
 
   String _filePathForSource(Source source) {
-    return source.toString();
+    return source.fullName;
   }
 
   /// Return the source information associated with the given [source], creating
diff --git a/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_information.dart b/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_information.dart
index 937cf9e..6510931 100644
--- a/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_information.dart
+++ b/pkg/analysis_server/lib/src/edit/nnbd_migration/instrumentation_information.dart
@@ -20,8 +20,8 @@
   /// The node used for type sources that are never `null`.
   NullabilityNodeInfo never;
 
-  /// Expando associating [NodeInformation] wich [NullabilityNodeInfo] objects.
-  Expando<NodeInformation> nodeInformation = Expando<NodeInformation>();
+  /// A map associating [NodeInformation] with [NullabilityNodeInfo] objects.
+  Map<NullabilityNodeInfo, NodeInformation> nodeInformation = {};
 
   /// A list of the steps in the propagation of nullability information through
   /// the nullability graph, to report details of the step that was performed